@@ -5,6 +5,7 @@
 # Licenced under GPLv3
 
 USE_PYSIDE = True
+USE_PYSIDE = False
 
 #Mega Import ! Beurk
 
@@ -13,6 +14,8 @@ if not USE_PYSIDE:
     sip.setapi('QString', 2)
     sip.setapi('QVariant', 2)
 
+    from PyQt4.QtCore import pyqtSlot,pyqtSignal
+
 #    from PyQt4.QtGui import *
 #    from PyQt4.QtCore import *
 
